.. _release_notes:

*************
Release Notes
*************

.. release:: 0.1.0
    :date: 2017-11-11

    .. change:: new
        :tags: command-line

        Added :option:`assemble target <jound assemble target>` option to
        generate a file with all sorted words contained in a targeted text
        (file or url).

    .. change:: new
        :tags: command-line

        Added :option:`analyze target <jound analyze target>` option to
        generate a statistical file recording the occurrence of each letter
        after a group of two letters.

    .. change:: new
        :tags: command-line

        Added :option:`generate number <jound generate number>` option to
        print out a list of N words computed from a :option:`statistical file
        <jound generate -s>`.
